#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Apr  4 11:10:20 2019

@author: martindrech

Por ahora, aca se va a crear una imagen cada cierto tiempo y eso se va a mandar a toy_gui para plotearse ahi
"""

import numpy as np
from PyQt5 import QtCore
#from drivers.andorzyla import AndorZyla
from dummyAndor import AndorZyla
import threading


class CameraWorker(QtCore.QObject):
    imageReadySignal = QtCore.pyqtSignal(np.ndarray)

    

    def __init__(self):     
        super(CameraWorker, self).__init__()
             
        self.cam = AndorZyla(0)
        self.cam.Init()
        self.cam.ExposureTime.setValue(.01)
        self.cam.FrameRate.setValue(20)

        
        
        
        print('camera worker initialized')
        
    def make_connections(self, frontend):
        #frontend connections
        frontend.cameraButton.clicked.connect(self.run)
        frontend.sb.valueChanged.connect(lambda x = frontend.sb.value(): self.cam.ExposureTime.setValue(x))
        
        #internal connections
        self.cam.helper.imageAquiredSignal.connect(self.acquire)

        
    def __del__(self):
        print('adios camera worker')

        
    @QtCore.pyqtSlot()
    def run(self):
        if self.cam.CameraAcquiring.getValue():
            self._stop_acquisition_loop()
            print('acquisition now stopping')
            
        else:
            self._start_acquisition_loop()
            self.acq_thread = threading.Thread(target= self.cam.live_acquisition_loop)
            self.acq_thread.start()
            print('acquisiting now starting')


    def _start_acquisition_loop(self):
        self.cam.live_acquisition_configure()     
        self.cam.AcquisitionStart()
        print('frame rate: ', self.cam.FrameRate.getValue())
        print('Exp time: ', self.cam.ExposureTime.getValue())

  
    def _stop_acquisition_loop(self):
        self.acq_thread.do_run = False
        self.acq_thread.join()
        self.cam.AcquisitionStop()
        self.cam._flush()


        
    @QtCore.pyqtSlot()
    def acquire(self):
        #print('acquiring')
        self.imageReadySignal.emit(self.cam.current_image)

